@@ -181,7 +181,7 @@ def calcFAS (outpath, extendedFa, weightpath, cpu):
         sys.exit('Problem running\n%s' % (fasCmd))
 
 def main():
-    version = '0.0.21'
+    version = '0.0.23'
     parser = argparse.ArgumentParser(description='You are running fdogs.run version ' + str(version) + '.')
     parser.add_argument('--version', action='version', version=str(version))
     required = parser.add_argument_group('Required arguments')
@@ -365,19 +365,20 @@ def main():
         with open(pathconfigFile) as f:
             dataPath = f.readline().strip()
     else:
-        cfg = load_config(pathFile)
+        cfg = fdogFn.load_config(pathFile)
         try:
             dataPath = cfg['dataPath']
         except:
             dataPath = 'config'
 
     if hmmpath == '':
-        hmmpath = dataPath + '/core_orthologs'
-        if dataPath == 'config':
-            try:
-                hmmpath = cfg['hmmpath']
-            except:
-                sys.exit('hmmpath not found in %s. Please check https://github.com/BIONF/fDOG/wiki/Input-and-Output-Files#data-structure' % pathFile)
+        hmmpath = outpath + '/core_orthologs'
+        # hmmpath = dataPath + '/core_orthologs'
+        # if dataPath == 'config':
+        #     try:
+        #         hmmpath = cfg['hmmpath']
+        #     except:
+        #         sys.exit('hmmpath not found in %s. Please check https://github.com/BIONF/fDOG/wiki/Input-and-Output-Files#data-structure' % pathFile)
     if blastpath == '':
         blastpath = dataPath + '/blast_dir'
         if dataPath == 'config':
